@@ -11,6 +11,11 @@ module Librarian
         "puppet"
       end
 
+      def tmp_path
+        part = config_db["tmp"] || ".tmp"
+        project_path.join(part)
+      end
+
       def install_path
         part = config_db["path"] || "modules"
         project_path.join(part)
@@ -28,14 +33,6 @@ module Librarian
         vendor_path.join('source')
       end
 
-      def cache_path
-        project_path.join(".tmp/librarian/cache")
-      end
-
-      def scratch_path
-        project_path.join(".tmp/librarian/scratch")
-      end
-
       def vendor!
         vendor_cache.mkpath  unless vendor_cache.exist?
         vendor_source.mkpath unless vendor_source.exist?
