@@ -4,19 +4,23 @@ module Librarian
       attr_reader :requirement
 
       def initialize(requirement)
-        @requirement = requirement
+        @requirement = requirement || ">=0"
       end
 
       def gem_requirement
         if range_requirement?
           [@range_match[1], @range_match[2]]
         elsif pessimistic_requirement?
-          "~> #{@pessimistic_match[1]}"
+          "~> #{@pessimistic_match[1]}.0"
         else
           requirement
         end
       end
 
+      def to_s
+        gem_requirement.to_s
+      end
+
       private
 
       def range_requirement?
